# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import enum

import winrt.system

__all__ = [
    "DragDropModifiers",
]

class DragDropModifiers(enum.IntFlag):
    NONE = 0x0
    SHIFT = 0x1
    CONTROL = 0x2
    ALT = 0x4
    LEFT_BUTTON = 0x8
    MIDDLE_BUTTON = 0x10
    RIGHT_BUTTON = 0x20




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

from winrt.windows.applicationmodel.datatransfer.dragdrop import DragDropModifiers

Self = typing.TypeVar('Self')

